# Generated by roxygen2: do not edit by hand

export("%>%")
export(bdc_basisOfRecords_notStandard)
export(bdc_clean_names)
export(bdc_coordinates_country_inconsistent)
export(bdc_coordinates_empty)
export(bdc_coordinates_from_locality)
export(bdc_coordinates_outOfRange)
export(bdc_coordinates_precision)
export(bdc_coordinates_transposed)
export(bdc_country_from_coordinates)
export(bdc_country_standardized)
export(bdc_create_figures)
export(bdc_create_report)
export(bdc_eventDate_empty)
export(bdc_filter_out_flags)
export(bdc_filter_out_names)
export(bdc_query_names_taxadb)
export(bdc_quickmap)
export(bdc_scientificName_empty)
export(bdc_standardize_datasets)
export(bdc_summary_col)
export(bdc_year_from_eventDate)
export(bdc_year_outOfRange)
importFrom(CoordinateCleaner,cc_sea)
importFrom(CoordinateCleaner,cc_val)
importFrom(CoordinateCleaner,clean_coordinates)
importFrom(DT,datatable)
importFrom(dplyr,across)
importFrom(dplyr,add_row)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,as_tibble)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,collect)
importFrom(dplyr,contains)
importFrom(dplyr,distinct)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,full_join)
importFrom(dplyr,group_by)
importFrom(dplyr,if_else)
importFrom(dplyr,intersect)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_all)
importFrom(dplyr,mutate_if)
importFrom(dplyr,n)
importFrom(dplyr,na_if)
importFrom(dplyr,pull)
importFrom(dplyr,recode)
importFrom(dplyr,relocate)
importFrom(dplyr,rename)
importFrom(dplyr,right_join)
importFrom(dplyr,select)
importFrom(dplyr,select_if)
importFrom(dplyr,slice)
importFrom(dplyr,summarise)
importFrom(dplyr,summarise_all)
importFrom(dplyr,sym)
importFrom(dplyr,tibble)
importFrom(foreach,"%dopar%")
importFrom(fs,dir_create)
importFrom(fs,dir_exists)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,coord_quickmap)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_col)
importFrom(ggplot2,geom_hex)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_polygon)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggsave)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_viridis_c)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(ggplot2,theme_void)
importFrom(ggplot2,unit)
importFrom(here,here)
importFrom(magrittr,"%>%")
importFrom(parallel,makeCluster)
importFrom(parallel,stopCluster)
importFrom(purrr,map_dfr)
importFrom(purrr,set_names)
importFrom(qs,qread)
importFrom(qs,qsave)
importFrom(readr,cols)
importFrom(readr,read_csv)
importFrom(readr,read_delim)
importFrom(readr,write_csv)
importFrom(rgnparser,gn_parse_tidy)
importFrom(rnaturalearth,ne_countries)
importFrom(sf,as_Spatial)
importFrom(sf,sf_use_s2)
importFrom(sf,st_as_sf)
importFrom(sf,st_buffer)
importFrom(sf,st_crs)
importFrom(sf,st_intersection)
importFrom(sf,st_intersects)
importFrom(sf,st_set_crs)
importFrom(stats,reorder)
importFrom(stringi,stri_trans_general)
importFrom(stringr,regex)
importFrom(stringr,str_count)
importFrom(stringr,str_detect)
importFrom(stringr,str_extract)
importFrom(stringr,str_length)
importFrom(stringr,str_remove_all)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_split_fixed)
importFrom(stringr,str_squish)
importFrom(stringr,str_to_lower)
importFrom(stringr,str_to_sentence)
importFrom(stringr,str_trim)
importFrom(stringr,str_which)
importFrom(taxadb,taxa_tbl)
importFrom(taxadb,td_connect)
importFrom(taxadb,td_create)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tidyselect,everything)
importFrom(tidyselect,starts_with)
importFrom(utils,head)
